ApiConsumer class abstract

Implementers

Constructors

ApiConsumer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
get(String path, {Map<String, String> headers}) Future<HttpResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
post(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
put(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited