DioConsumer class

Implemented types
Annotations
  • @LazySingleton.new(as: ApiConsumer)

Constructors

DioConsumer({required Dio dio})

Properties

dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
override
get(String path, {Map<String, String>? headers}) Future<HttpResponse>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
override
post(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
override
put(String path, {Object? body, Map<String, String>? headers}) Future<HttpResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited