LocalDatabase class
A class that provides methods for interacting with a local database.
- Annotations
-
- @lazySingleton
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getToken(
) → String - Retrieves the token from the configuration file.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveUserInfo(
{required Map< String, dynamic> userData}) → Future<void> - Saves the userData to the configuration file.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited