ServerException class

Exception thrown when there is a server error.

Implemented types

Constructors

ServerException({String? msg})
Creates a new instance of ServerException with an optional error message.

Properties

hashCode int
The hash code for this object.
no setterinherited
msg String?
The error message associated with the exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited