TokenNotFoundException class

Exception thrown when a token is not found.

Implemented types

Constructors

TokenNotFoundException({String? msg})
Creates a new instance of TokenNotFoundException with an optional error message.

Properties

hashCode int
The hash code for this object.
no setterinherited
msg String?
The error message associated with the exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited