BricksManager class

Annotations
  • @lazySingleton

Constructors

BricksManager({required UsedPackages usedPackages})

Properties

depPackagesNames List<String>
final
depPackagesOfYaml Map<String, dynamic>
final
devDepPackagesNames List<String>
final
devDepPackgesOfyaml Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usedPackages UsedPackages
final

Methods

executeBrickAndGetPackages({required CliBrick brick}) Future<void>
generateBricks() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited