CliBrick class abstract

Implementers

Constructors

CliBrick()

Properties

depPackages Map<String, String>
no setter
devDepPackages Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
packageName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeBrick() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cliBricks Map<String, CliBrick>
final

Constants

none → const String