CreateFlutterProject class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
logger
→ Logger
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shell
→ Shell
-
final
Methods
-
call({required String projectName})
→ Future
-
Creates a new Flutter project with the given
projectName.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited