DatasourceFileManager class

Annotations
  • @lazySingleton

Constructors

DatasourceFileManager({required FileHandler fileHandler})

Properties

fileHandler FileHandler
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postAppendDataSource({required String featureName, required String newFunction}) Future<void>
Appends a new function to the data source file of a specific feature.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited