InteractManager class
- Implemented types
- Annotations
-
- @LazySingleton.new(as: ForgeInteract)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
confirm(
{required String prompt, bool defaultValue = false}) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
select(
{required String prompt, required List< String> options}) → ({int index, String selectd}) -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited