UsedPackages class

Annotations
  • @singleton

Constructors

UsedPackages({required ForgeInteract interact})

Properties

hashCode int
The hash code for this object.
no setterinherited
no setter
packages List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateManagement String
no setter
withLocalization bool
no setter

Methods

getNetworkingPackage() String
getPackagesWhenCreateForgeConfig() Future<void>
getPackagesWhenCreateProject() Future<void>
getRoutingPackage() String
getStateManagementPackage() String
getStoragePackage() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withLocalizationPackage() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited