ValidatorsImpl class

Implementation of the Validators interface.

Implemented types
Annotations
  • @LazySingleton.new(as: Validators)

Constructors

ValidatorsImpl({required Logger logger})
Creates a new instance of ValidatorsImpl with the given logger.

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isFeatureFound({required String featureName}) → void
Checks if a feature with the given featureName exists.
override
isValidCurrentPath() → void
Checks if the current path is valid for a Flutter project.
override
isValidStateManagement(String? stateManagement) bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectFound({required String folderName}) → void
Checks if a project with the given folderName exists.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited