AuthDataSourceImpl class

Implemented types
Annotations
  • @LazySingleton.new(as: AuthDataSource)

Constructors

AuthDataSourceImpl({required ApiConsumer apiConsumer})

Properties

apiConsumer ApiConsumer
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDeviceAuthStatus(AuthEntity enity) Future<AuthModel>
override
deviceAuth(AuthEntity enity) Future<Unit>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited