CheckAuthStatusManager class

Annotations
  • @lazySingleton

Constructors

CheckAuthStatusManager({required Logger logger, required CheckDeviceAuthStatusUseCase checkDeviceAuthStatusUseCase, required LocalDatabase localDatabase})

Properties

checkDeviceAuthStatusUseCase CheckDeviceAuthStatusUseCase
final
hashCode int
The hash code for this object.
no setterinherited
localDatabase LocalDatabase
final
logger → Logger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUserData({required String otpCode}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited