BuildEntity class

Represents a build entity.

Constructors

BuildEntity({required String code, required String featureName, required List? featureConfig, required Map<String, dynamic> forgeCliConfig})
Constructs a BuildEntity instance.

Properties

code String
The code of the build entity.
final
featureConfig List?
The old configuration of the build entity.
final
featureName String
The feature name of the build entity.
final
forgeCliConfig Map<String, dynamic>
forge cli config of the project
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BuildEntity instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited