GetGeneratedCodeFromApi class
- Annotations
-
- @lazySingleton
Constructors
- GetGeneratedCodeFromApi({required BuildCmdUseCase buildCmdUseCase, required Logger logger, required ForgeConfigManager forgeConfigManager})
Properties
- buildCmdUseCase → BuildCmdUseCase
-
final
- forgeConfigManager → ForgeConfigManager
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{required List? configFnList, required String dartCode}) → Future< BuildModel> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited