PackagesVersion class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- build_runner → const String
- connectivity_plus → const String
- cupertino_icons → const String
- dartz → const String
- dio → const String
- easyLocalization → const String
- equatable → const String
- flutter_dotenv → const String
- flutter_gen_runner → const String
- flutter_lints → const String
- flutter_secure_storage → const String
- flutter_svg → const String
- flutterBloc → const String
- forge_annotation → const String
- freezed → const String
- freezed_annotation → const String
- get_it → const String
- go_router_builder → const String
- goRouter → const String
- hive → const String
- http → const String
- injectable → const String
- injectable_generator → const String
- pathProvider → const String