StringManipulation extension
Extension on the String class that provides additional methods for string manipulation.
- on
Methods
-
containsOnlyOnePeriod(
) → bool -
Available on String, provided by the StringManipulation extension
Checks if a file name contains only one period. -
decodedBase64(
) → String -
Available on String, provided by the StringManipulation extension
Decodes a base64 encoded string and returns the decoded data as a UTF-8 string. -
insertStringAtPosition(
{required String input, required String positionOf}) → String -
Available on String, provided by the StringManipulation extension
Inserts a giveninputstring at the position right after the first occurrence of an opening curly bracket ('{'). -
removeLastCurlyBrackets(
) → String -
Available on String, provided by the StringManipulation extension
Removes the last occurrence of curly brackets ('}') from the string. -
toPascalCase(
) → String -
Available on String, provided by the StringManipulation extension
Converts the string to PascalCase. -
toSnakeCase(
) → String -
Available on String, provided by the StringManipulation extension
Converts a string to snake case.