FileHandler class
- Annotations
-
- @lazySingleton
Constructors
- FileHandler({required Logger logger})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createFile(
{required String filePath, required String data, FileMode modeIfExist = FileMode.append}) → Future< void> -
Appends the given
datato a file at the specifiedfilePath. If the file does not exist, it will be created. -
getFileOrDirectoryListFromPath<
T extends FileSystemEntity> ({required String path}) → Future< List< T> > - final path = 'lib/features/home/domain/repositories/';
-
isFileExist(
{required String filePath}) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readFromFile(
{required String filePath}) → Future< String?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited