LoginManager class
- Annotations
-
- @lazySingleton
Constructors
- LoginManager({required Logger logger, required DeviceAuthManager deviceAuthManager, required CheckAuthStatusManager checkStatusManager})
Properties
- checkStatusManager → CheckAuthStatusManager
-
final
- deviceAuthManager → DeviceAuthManager
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- randomString ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listenToPressedKey(
) → void -
loginLogger(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendOtpCodeToForge(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
tryGetToken(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited