PrePostGen class
A class that contains methods for post-generation tasks.
- Annotations
-
- @lazySingleton
Constructors
- PrePostGen({required Logger logger, required BricksManager bricksManager})
Properties
- bricksManager → BricksManager
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shell → Shell
-
final
Methods
-
dartFix(
) → Future< void> -
Runs the
dart fix --applycommand to fix Dart warnings or unused imports. -
displayUsedPackages(
) → void -
formatAll(
) → Future< void> - Formats all Dart files in the current directory and its subdirectories.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postBuild(
) → Future< void> -
runBuildRunner(
{bool withLog = false}) → Future< void> - Runs the build runner command to generate code using build_runner.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited