PubspecManager class
- Annotations
-
- @lazySingleton
Constructors
- PubspecManager({required FileHandler fileHandler, required BricksManager bricksManager})
Properties
- bricksManager → BricksManager
-
final
- fileHandler → FileHandler
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateYamlFile(
) → Future< void> - Edits the pubspec.yaml file to add custom assets and dependencies.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited