Validators class abstract
Abstract class defining the contract for validators.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isFeatureFound(
{required String featureName}) → void -
Checks if a feature with the given
featureNameexists. -
isValidCurrentPath(
) → void - Checks if the current path is valid for a Flutter project.
-
isValidStateManagement(
String? stateManagement) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
projectFound(
{required String folderName}) → void -
Checks if a project with the given
folderNameexists. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited