BuildModel class
Represents a build model.
Constructors
-
BuildModel({required Map<
String, dynamic> genCode, required List listFunctionsName, String? abstractToAppend}) -
Constructs a BuildModel instance.
const
-
BuildModel.fromJson(Map<
String, dynamic> json) -
Constructs a BuildModel instance from a JSON object.
factory
Properties
- abstractToAppend → String?
-
The abstract to append.
final
-
genCode
→ Map<
String, dynamic> -
The generated code.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- listFunctionsName → List
-
The list of function names.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the BuildModel instance to a JSON object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited